@@ -22,76 +22,80 @@
  *          Lucas Rocha <lucasr@im.ufba.br>
  */
 
+#include "config.h"
+
 #include "option.h"
 #include <time.h>
+#include <stdlib.h>
+#include <string.h>
 
 /* General Options */
-gchar   *zenity_general_dialog_title;
-gchar   *zenity_general_window_icon;
-int      zenity_general_width;
-int      zenity_general_height;
-gchar   *zenity_general_dialog_text;
-gchar   *zenity_general_separator;
-gboolean zenity_general_multiple;
-gboolean zenity_general_editable;
-gchar   *zenity_general_uri;
-gboolean zenity_general_dialog_no_wrap;
+static gchar   *zenity_general_dialog_title;
+static gchar   *zenity_general_window_icon;
+static int      zenity_general_width;
+static int      zenity_general_height;
+static gchar   *zenity_general_dialog_text;
+static gchar   *zenity_general_separator;
+static gboolean zenity_general_multiple;
+static gboolean zenity_general_editable;
+static gchar   *zenity_general_uri;
+static gboolean zenity_general_dialog_no_wrap;
 
 /* Calendar Dialog Options */
-gboolean zenity_calendar_active;
-int      zenity_calendar_day;
-int      zenity_calendar_month;
-int      zenity_calendar_year;
-gchar   *zenity_calendar_date_format;
+static gboolean zenity_calendar_active;
+static int      zenity_calendar_day;
+static int      zenity_calendar_month;
+static int      zenity_calendar_year;
+static gchar   *zenity_calendar_date_format;
 
 /* Entry Dialog Options */
-gboolean zenity_entry_active;
-gchar   *zenity_entry_entry_text;
-gboolean zenity_entry_hide_text;
+static gboolean zenity_entry_active;
+static gchar   *zenity_entry_entry_text;
+static gboolean zenity_entry_hide_text;
 
 /* Error Dialog Options */
-gboolean zenity_error_active;
+static gboolean zenity_error_active;
 
 /* Info Dialog Options */
-gboolean zenity_info_active;
+static gboolean zenity_info_active;
 
 /* File Selection Dialog Options */
-gboolean zenity_file_active;
-gboolean zenity_file_directory;
-gboolean zenity_file_save;
+static gboolean zenity_file_active;
+static gboolean zenity_file_directory;
+static gboolean zenity_file_save;
 
 /* List Dialog Options */
-gboolean zenity_list_active;
-gchar  **zenity_list_columns;
-gboolean zenity_list_checklist;
-gboolean zenity_list_radiolist;
-gchar   *zenity_list_print_column;
-gchar   *zenity_list_hide_column;
+static gboolean zenity_list_active;
+static gchar  **zenity_list_columns;
+static gboolean zenity_list_checklist;
+static gboolean zenity_list_radiolist;
+static gchar   *zenity_list_print_column;
+static gchar   *zenity_list_hide_column;
 
 /* Notification Dialog Options */
-gboolean zenity_notification_active;
-gboolean zenity_notification_listen;
+static gboolean zenity_notification_active;
+static gboolean zenity_notification_listen;
 
 /* Progress Dialog Options */
-gboolean zenity_progress_active;
-int      zenity_progress_percentage;
-gboolean zenity_progress_pulsate;
-gboolean zenity_progress_auto_close;
+static gboolean zenity_progress_active;
+static int      zenity_progress_percentage;
+static gboolean zenity_progress_pulsate;
+static gboolean zenity_progress_auto_close;
 
 /* Question Dialog Options */
-gboolean zenity_question_active;
+static gboolean zenity_question_active;
 
 /* Text Dialog Options */
-gboolean zenity_text_active;
+static gboolean zenity_text_active;
 
 /* Warning Dialog Options */
-gboolean zenity_warning_active;
+static gboolean zenity_warning_active;
 
 /* Miscelaneus Options */
-gboolean zenity_misc_about;
-gboolean zenity_misc_version;
+static gboolean zenity_misc_about;
+static gboolean zenity_misc_version;
 
-GOptionEntry general_options[] = {
+static GOptionEntry general_options[] = {
   {
     "title",
     '\0',
@@ -133,7 +137,7 @@ GOptionEntry general_options[] = {
   }
 };
 
-GOptionEntry calendar_options[] = {
+static GOptionEntry calendar_options[] = {
   {
     "calendar",
     '\0',
@@ -146,7 +150,7 @@ GOptionEntry calendar_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
@@ -193,7 +197,7 @@ GOptionEntry calendar_options[] = {
   } 
 };
 
-GOptionEntry entry_options[] = {
+static GOptionEntry entry_options[] = {
   {
     "entry",
     '\0',
@@ -206,8 +210,8 @@ GOptionEntry entry_options[] = {
   {
     "text",
     '\0',
-    0,
-    G_OPTION_ARG_STRING,
+    G_OPTION_FLAG_NOALIAS,
+    G_OPTION_ARG_STRING | G_OPTION_FLAG_NOALIAS,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
     NULL
@@ -236,7 +240,7 @@ GOptionEntry entry_options[] = {
 };
 
 
-GOptionEntry error_options[] = {
+static GOptionEntry error_options[] = {
   {
     "error",
     '\0',
@@ -249,7 +253,7 @@ GOptionEntry error_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
@@ -258,7 +262,7 @@ GOptionEntry error_options[] = {
   {
     "no-wrap",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_NONE,
     &zenity_general_dialog_no_wrap,
     N_("Do not enable text wrapping"),
@@ -269,7 +273,7 @@ GOptionEntry error_options[] = {
   } 
 };
 
-GOptionEntry info_options[] = {
+static GOptionEntry info_options[] = {
   {
     "info",
     '\0',
@@ -282,7 +286,7 @@ GOptionEntry info_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
@@ -291,7 +295,7 @@ GOptionEntry info_options[] = {
   {
     "no-wrap",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_NONE,
     &zenity_general_dialog_no_wrap,
     N_("Do not enable text wrapping"),
@@ -302,7 +306,7 @@ GOptionEntry info_options[] = {
   }
 };
 
-GOptionEntry file_selection_options[] = {
+static GOptionEntry file_selection_options[] = {
   {
     "file-selection",
     '\0',
@@ -315,7 +319,7 @@ GOptionEntry file_selection_options[] = {
   {
     "filename",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_FILENAME,
     &zenity_general_uri,
     N_("Set the filename"),
@@ -324,7 +328,7 @@ GOptionEntry file_selection_options[] = {
   {
     "multiple",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_NONE,
     &zenity_general_multiple,
     N_("Allow multiple files to be selected"),
@@ -351,7 +355,7 @@ GOptionEntry file_selection_options[] = {
   {
     "separator",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_separator,
     N_("Set output separator character"),
@@ -362,7 +366,7 @@ GOptionEntry file_selection_options[] = {
   } 
 };
 
-GOptionEntry list_options[] = {
+static GOptionEntry list_options[] = {
   {
     "list",
     '\0',
@@ -375,7 +379,7 @@ GOptionEntry list_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
@@ -420,7 +424,7 @@ GOptionEntry list_options[] = {
   {
     "multiple",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_NONE,
     &zenity_general_multiple,
     N_("Allow multiple rows to be selected"),
@@ -429,7 +433,7 @@ GOptionEntry list_options[] = {
   {
     "editable",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_NONE,
     &zenity_general_editable,
     N_("Allow changes to text"),
@@ -458,7 +462,7 @@ GOptionEntry list_options[] = {
   } 
 };
 
-GOptionEntry notification_options[] = {
+static GOptionEntry notification_options[] = {
   {
     "notification",
     '\0',
@@ -471,7 +475,7 @@ GOptionEntry notification_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the notification text"),
@@ -491,7 +495,7 @@ GOptionEntry notification_options[] = {
   }
 };
 
-GOptionEntry progress_options[] = {
+static GOptionEntry progress_options[] = {
   {
     "progress",
     '\0',
@@ -504,7 +508,7 @@ GOptionEntry progress_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
@@ -543,7 +547,7 @@ GOptionEntry progress_options[] = {
   }
 };
 
-GOptionEntry question_options[] = {
+static GOptionEntry question_options[] = {
   {
     "question",
     '\0',
@@ -556,7 +560,7 @@ GOptionEntry question_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
@@ -565,7 +569,7 @@ GOptionEntry question_options[] = {
   {
     "no-wrap",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_NONE,
     &zenity_general_dialog_no_wrap,
     N_("Do not enable text wrapping"),
@@ -576,7 +580,7 @@ GOptionEntry question_options[] = {
   }
 };
 
-GOptionEntry text_options[] = {
+static GOptionEntry text_options[] = {
   {
     "text-info",
     '\0',
@@ -589,7 +593,7 @@ GOptionEntry text_options[] = {
   {
     "filename",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_FILENAME,
     &zenity_general_uri,
     N_("Open file"),
@@ -598,7 +602,7 @@ GOptionEntry text_options[] = {
   {
     "editable",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_NONE,
     &zenity_general_editable,
     N_("Allow changes to text"),
@@ -609,7 +613,7 @@ GOptionEntry text_options[] = {
   }
 };
 
-GOptionEntry warning_options[] = {
+static GOptionEntry warning_options[] = {
   {
     "warning",
     '\0',
@@ -622,7 +626,7 @@ GOptionEntry warning_options[] = {
   {
     "text",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
@@ -631,7 +635,7 @@ GOptionEntry warning_options[] = {
   {
     "no-wrap",
     '\0',
-    0,
+    G_OPTION_FLAG_NOALIAS,
     G_OPTION_ARG_NONE,
     &zenity_general_dialog_no_wrap,
     N_("Do not enable text wrapping"),
@@ -642,7 +646,7 @@ GOptionEntry warning_options[] = {
   }
 };
 
-GOptionEntry miscellaneous_options[] = {
+static GOptionEntry miscellaneous_options[] = {
   {
     "about",
     '\0',
@@ -666,10 +670,10 @@ GOptionEntry miscellaneous_options[] = {
   }
 };
 
-ZenityParsingOptions *results;
-GOptionContext *ctx;
+static ZenityParsingOptions *results;
+static GOptionContext *ctx;
 
-void
+static void
 zenity_option_init (void) {
 
   results = g_new0 (ZenityParsingOptions, 1);
@@ -715,7 +719,7 @@ zenity_option_free (void) {
   g_option_context_free (ctx);
 }
 
-void
+static void
 zenity_option_set_dialog_mode (gboolean is_active, ZenityDialogMode mode)  
 {
   if (is_active == TRUE) {
@@ -726,7 +730,7 @@ zenity_option_set_dialog_mode (gboolean is_active, ZenityDialogMode mode)
   }
 }
 
-gchar *
+static gchar *
 zenity_option_get_name (GOptionEntry *entries, gpointer arg_data)
 {
   int i;
@@ -739,17 +743,18 @@ zenity_option_get_name (GOptionEntry *entries, gpointer arg_data)
 }
 
 /* Error callback */
-void zenity_option_error_callback (GOptionContext *context,
-				   GOptionGroup   *group,
-				   gpointer        data,
-				   GError        **error)
+static void 
+zenity_option_error_callback (GOptionContext *context,
+                              GOptionGroup   *group,
+			      gpointer        data,
+			      GError        **error)
 {
   zenity_option_error (NULL, ERROR_SYNTAX);
 }
 
 /* Pre parse callbacks set the default option values */
 
-gboolean
+static gboolean
 zenity_general_pre_callback (GOptionContext *context,
 		             GOptionGroup   *group,
 		             gpointer	     data,
@@ -769,7 +774,7 @@ zenity_general_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_calendar_pre_callback (GOptionContext *context,
 		              GOptionGroup   *group,
 		              gpointer        data,
@@ -784,7 +789,7 @@ zenity_calendar_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_entry_pre_callback (GOptionContext *context,
 		           GOptionGroup   *group,
 		           gpointer	   data,
@@ -797,7 +802,7 @@ zenity_entry_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_error_pre_callback (GOptionContext *context,
 		           GOptionGroup   *group,
 		           gpointer	   data,
@@ -808,7 +813,7 @@ zenity_error_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_info_pre_callback (GOptionContext *context,
 		          GOptionGroup   *group,
 		          gpointer	  data,
@@ -819,7 +824,7 @@ zenity_info_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_file_pre_callback (GOptionContext *context,
 		          GOptionGroup   *group,
 		          gpointer	  data,
@@ -832,7 +837,7 @@ zenity_file_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_list_pre_callback (GOptionContext *context,
 		          GOptionGroup   *group,
 		          gpointer	  data,
@@ -848,7 +853,7 @@ zenity_list_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_notification_pre_callback (GOptionContext *context,
 		                  GOptionGroup   *group,
 		                  gpointer	  data,
@@ -860,7 +865,7 @@ zenity_notification_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_progress_pre_callback (GOptionContext *context,
 		              GOptionGroup   *group,
 		              gpointer	      data,
@@ -874,7 +879,7 @@ zenity_progress_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_question_pre_callback (GOptionContext *context,
 		              GOptionGroup   *group,
 		              gpointer	      data,
@@ -885,7 +890,7 @@ zenity_question_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_text_pre_callback (GOptionContext *context,
 		          GOptionGroup   *group,
 		          gpointer	  data,
@@ -896,7 +901,7 @@ zenity_text_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_warning_pre_callback (GOptionContext *context,
 		             GOptionGroup   *group,
 		             gpointer	     data,
@@ -907,7 +912,7 @@ zenity_warning_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_misc_pre_callback (GOptionContext *context,
 		          GOptionGroup   *group,
 		          gpointer	  data,
@@ -922,7 +927,7 @@ zenity_misc_pre_callback (GOptionContext *context,
 /* Post parse callbacks assign the option values to
    parsing result and makes some post condition tests */
 
-gboolean
+static gboolean
 zenity_general_post_callback (GOptionContext *context,
 		              GOptionGroup   *group,
 		              gpointer	      data,
@@ -936,14 +941,12 @@ zenity_general_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_calendar_post_callback (GOptionContext *context,
 		               GOptionGroup   *group,
 		               gpointer	       data,
 		               GError        **error)
 {
-  int i;
-
   zenity_option_set_dialog_mode (zenity_calendar_active, MODE_CALENDAR);
 
   if (results->mode == MODE_CALENDAR) {
@@ -990,7 +993,7 @@ zenity_calendar_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_entry_post_callback (GOptionContext *context,
 		            GOptionGroup   *group,
 		            gpointer	    data,
@@ -1015,7 +1018,7 @@ zenity_entry_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_error_post_callback (GOptionContext *context,
 		            GOptionGroup   *group,
 		            gpointer	    data,
@@ -1032,7 +1035,7 @@ zenity_error_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_info_post_callback (GOptionContext *context,
 		           GOptionGroup   *group,
 		           gpointer	   data,
@@ -1049,7 +1052,7 @@ zenity_info_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_file_post_callback (GOptionContext *context,
 		           GOptionGroup   *group,
 		           gpointer	   data,
@@ -1076,7 +1079,7 @@ zenity_file_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_list_post_callback (GOptionContext *context,
 		           GOptionGroup   *group,
 		           gpointer	   data,
@@ -1130,7 +1133,7 @@ zenity_list_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_notification_post_callback (GOptionContext *context,
 		                   GOptionGroup   *group,
 		                   gpointer	   data,
@@ -1150,7 +1153,7 @@ zenity_notification_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_progress_post_callback (GOptionContext *context,
 		               GOptionGroup   *group,
 		               gpointer	       data,
@@ -1180,7 +1183,7 @@ zenity_progress_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_question_post_callback (GOptionContext *context,
 		               GOptionGroup   *group,
 		               gpointer	       data,
@@ -1198,7 +1201,7 @@ zenity_question_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_text_post_callback (GOptionContext *context,
 		           GOptionGroup   *group,
 		           gpointer	   data,
@@ -1214,7 +1217,7 @@ zenity_text_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_warning_post_callback (GOptionContext *context,
 		              GOptionGroup   *group,
 		              gpointer	      data,
@@ -1231,7 +1234,7 @@ zenity_warning_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-gboolean
+static gboolean
 zenity_misc_post_callback (GOptionContext *context,
 		           GOptionGroup   *group,
 		           gpointer	   data,
@@ -1243,7 +1246,7 @@ zenity_misc_post_callback (GOptionContext *context,
   return TRUE;
 }
 
-GOptionContext *
+static GOptionContext *
 zenity_create_context (void) 
 {
   GOptionContext *tmp_ctx;
@@ -1259,6 +1262,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_general_pre_callback, zenity_general_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds calendar option entries */
@@ -1269,6 +1273,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_calendar_pre_callback, zenity_calendar_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds entry option entries */
@@ -1279,6 +1284,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_entry_pre_callback, zenity_entry_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds error option entries */
@@ -1289,6 +1295,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_error_pre_callback, zenity_error_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds info option entries */
@@ -1299,6 +1306,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_info_pre_callback, zenity_info_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds file selection option entries */
@@ -1309,6 +1317,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_file_pre_callback, zenity_file_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds list option entries */
@@ -1319,6 +1328,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_list_pre_callback, zenity_list_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds notification option entries */
@@ -1329,6 +1339,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_notification_pre_callback, zenity_notification_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds progress option entries */
@@ -1339,6 +1350,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_progress_pre_callback, zenity_progress_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds question option entries */
@@ -1349,6 +1361,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_question_pre_callback, zenity_question_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds warning option entries */
@@ -1359,6 +1372,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_warning_pre_callback, zenity_warning_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds text option entries */
@@ -1369,6 +1383,7 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_text_pre_callback, zenity_text_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds misc option entries */
@@ -1379,10 +1394,12 @@ zenity_create_context (void)
   g_option_group_set_parse_hooks (a_group,
                     zenity_misc_pre_callback, zenity_misc_post_callback);
   g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Adds gtk option entries */
   a_group = gtk_get_option_group(TRUE);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
   /* Enable help options */
